@@ -4,7 +4,7 @@ use warnings;
 
 package Gentoo::Util::VirtualDepend;
 
-our $VERSION = '0.002005';
+our $VERSION = '0.003000';
 
 # ABSTRACT: Hard-coded replacements for perl-core/ dependencies and dependencies with odd names in Gentoo
 
@@ -118,6 +118,21 @@ sub get_modules_in_gentoo_package {
   return @{ $GENTOO2MOD{$package} || [] };
 }
 
+sub get_known_gentoo_packages {
+  _load_dist2gentoo unless $DIST2GENTOO_LOADED;
+  return keys %GENTOO2DIST;
+}
+
+sub get_known_dists {
+  _load_dist2gentoo unless $DIST2GENTOO_LOADED;
+  return keys %DIST2GENTOO;
+}
+
+sub get_known_modules {
+  _load_mod2gentoo unless $MOD2GENTOO_LOADED;
+  return keys %MOD2GENTOO;
+}
+
 sub module_is_perl {
   my ( $self, $opts, $module, $mod_version ) = @_;
   if ( not ref $opts ) {
@@ -188,7 +203,7 @@ Gentoo::Util::VirtualDepend - Hard-coded replacements for perl-core/ dependencie
 
 =head1 VERSION
 
-version 0.002005
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -320,6 +335,24 @@ Returns a list of C<CPAN> Distributions that map to this dependency.
 
 Returns a list of modules that map to this dependency.
 
+=head2 get_known_gentoo_packages
+
+  my @list = $v->get_known_gentoo_packages
+
+Returns a list of Gentoo packages for which there are known overrides.
+
+=head2 get_known_dists
+
+  my @list = $v->get_known_dists
+
+Returns a list of C<CPAN> Distributions for which there are known overrides
+
+=head2 get_known_modules
+
+  my @list = $v->get_known_modules
+
+Return a list of C<CPAN> Modules for which there are known overrides
+
 =head2 module_is_perl
 
 This function determines if it is "safe" to assume availability
